datastructuretools.TreeNode
===========================

.. abjad-lineage:: abjad.tools.datastructuretools.TreeNode.TreeNode

.. autoclass:: abjad.tools.datastructuretools.TreeNode.TreeNode

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TreeNode.TreeNode.depth
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.depthwise_inventory
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.graph_order
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.improper_parentage
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.name
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.parent
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.proper_parentage
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.root
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.__copy__
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.__deepcopy__
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.__eq__
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.__format__
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.__ne__
      ~abjad.tools.datastructuretools.TreeNode.TreeNode.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.depth
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.graph_order
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.parent
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.TreeNode.TreeNode.name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.__copy__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TreeNode.TreeNode.__repr__
   :noindex:
